<?php

namespace Marius\RealEstate1.0\Policies;

use Litepie\User\Contracts\UserPolicy;
use Marius\RealEstate1.0\Models\Propety;

class PropetyPolicy
{

    /**
     * Determine if the given user can view the propety.
     *
     * @param UserPolicy $user
     * @param Propety $propety
     *
     * @return bool
     */
    public function view(UserPolicy $user, Propety $propety)
    {
        if ($user->canDo('real_estate1.0.propety.view') && $user->isAdmin()) {
            return true;
        }

        return $propety->user_id == user_id() && $propety->user_type == user_type();
    }

    /**
     * Determine if the given user can create a propety.
     *
     * @param UserPolicy $user
     * @param Propety $propety
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('real_estate1.0.propety.create');
    }

    /**
     * Determine if the given user can update the given propety.
     *
     * @param UserPolicy $user
     * @param Propety $propety
     *
     * @return bool
     */
    public function update(UserPolicy $user, Propety $propety)
    {
        if ($user->canDo('real_estate1.0.propety.edit') && $user->isAdmin()) {
            return true;
        }

        return $propety->user_id == user_id() && $propety->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given propety.
     *
     * @param UserPolicy $user
     * @param Propety $propety
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Propety $propety)
    {
        return $propety->user_id == user_id() && $propety->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given propety.
     *
     * @param UserPolicy $user
     * @param Propety $propety
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Propety $propety)
    {
        if ($user->canDo('real_estate1.0.propety.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given propety.
     *
     * @param UserPolicy $user
     * @param Propety $propety
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Propety $propety)
    {
        if ($user->canDo('real_estate1.0.propety.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
