<?php

namespace Marius\RealEstate1.0\Providers;

use Illuminate\Support\ServiceProvider;

class RealEstate1.0ServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'real_estate1.0');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'real_estate1.0');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerRealEstate1.0();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerRealEstate1.0()
    {
        $this->app->bind('real_estate1.0', function($app) {
            return new RealEstate1.0($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('RealEstate1.0', 'Lavalite\RealEstate1.0\Facades\RealEstate1.0');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('marius.real_estate1.0', function ($app) {
            return $this->app->make('Marius\RealEstate1.0\RealEstate1.0');
        });

                // Bind Propety to repository
        $this->app->bind(
            'Marius\RealEstate1.0\Interfaces\PropetyRepositoryInterface',
            \Marius\RealEstate1.0\Repositories\Eloquent\PropetyRepository::class
        );

        $this->app->register(\Marius\RealEstate1.0\Providers\AuthServiceProvider::class);
                $this->app->register(\Marius\RealEstate1.0\Providers\EventServiceProvider::class);
        
        $this->app->register(\Marius\RealEstate1.0\Providers\RouteServiceProvider::class);
                $this->app->register(\Marius\RealEstate1.0\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and real_estate1.0's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/real_estate1.0.php', 'real_estate1.0'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeRealEstate1.0::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['marius.real_estate1.0'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('marius/real_estate1.0.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/real_estate1.0')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/real_estate1.0')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
