<?php

namespace Marius\RealEstate1.0\Workflow;

use Marius\RealEstate1.0\Models\Propety;
use Validator;

class PropetyValidator
{

    /**
     * Determine if the given propety is valid for complete status.
     *
     * @param Propety $propety
     *
     * @return bool / Validator
     */
    public function complete(Propety $propety)
    {
        return Validator::make($propety->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given propety is valid for verify status.
     *
     * @param Propety $propety
     *
     * @return bool / Validator
     */
    public function verify(Propety $propety)
    {
        return Validator::make($propety->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given propety is valid for approve status.
     *
     * @param Propety $propety
     *
     * @return bool / Validator
     */
    public function approve(Propety $propety)
    {
        return Validator::make($propety->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given propety is valid for publish status.
     *
     * @param Propety $propety
     *
     * @return bool / Validator
     */
    public function publish(Propety $propety)
    {
        return Validator::make($propety->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given propety is valid for archive status.
     *
     * @param Propety $propety
     *
     * @return bool / Validator
     */
    public function archive(Propety $propety)
    {
        return Validator::make($propety->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given propety is valid for unpublish status.
     *
     * @param Propety $propety
     *
     * @return bool / Validator
     */
    public function unpublish(Propety $propety)
    {
        return Validator::make($propety->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
